# Generated by Django 2.1.7 on 2019-02-27 07:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_support_lite', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ticket',
            name='priority',
            field=models.IntegerField(choices=[(0, 'Low'), (1, 'Normal'), (2, 'High')]),
        ),
    ]
